* Pierre Lorenzon (2007-07-16) writes:

> I already send a bug report a few days ago. Now investigating
> the code more carefully I wonder why ther are this two lines of
> code at line 1831 in the tex.el file :
>
>                 (setq default-directory (expand-file-name
>                                          (file-name-directory
>                                          style))
>
> It does semme consistant with the way the master-dir is set
> (relatively) at line 1742 in the tex.el file :
>
>               (master-dir (if (stringp TeX-master)
>                               (file-name-directory
>                                (file-relative-name TeX-master))
>                             "./"))

Can you check if the following patch works for you?

--- tex.el      09 Jul 2007 21:31:18 +0200      5.610
+++ tex.el      19 Jul 2007 22:32:20 +0200      
@@ -1844,9 +1844,9 @@
              (let ((default-directory default-directory))
                ;; Complex path.
                (when (string-match "\\`\\(.+[/\\]\\)\\([^/\\]*\\)\\'" style)
-                 ;; Adjust `default-directory' to the directory of the style.
-                 (setq default-directory (expand-file-name
-                                          (file-name-directory style))
+                 ;; Set `default-directory' to directory of master file.
+                 (setq default-directory (save-match-data
+                                           (TeX-master-directory))
                        style (substring style
                                         (match-beginning 2) (match-end 2))))
                (mapcar 'funcall

-- 
Ralf


_______________________________________________
bug-auctex mailing list
[email protected]
http://lists.gnu.org/mailman/listinfo/bug-auctex

Reply via email to